==> haskell-hslua-module-system-0.2.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-YxbK1eU7YiKX9w6VSHuI7
key: hslua-module-system-0.2.1-YxbK1eU7YiKX9w6VSHuI7
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: fa5287c28751ea7d0a981d9f84511777
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-YxbK1eU7YiKX9w6VSHuI7
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
    hslua-1.0.3.1-3H2ZarpkwWd8Ko2IsQjuGp
    temporary-1.3-FE2pFZ9dWIB3eDQ0WTL5GN
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-3iaDyok1RoGIjZriAaEf7x
key: hslua-module-system-0.2.1-3iaDyok1RoGIjZriAaEf7x
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: 87109afb6d16aa3373978401e7bb0572
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-3iaDyok1RoGIjZriAaEf7x
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
    hslua-1.0.3.1-7o2fbmDolMq8lUdvfRqqUS
    temporary-1.3-DtA9I5S66596vhEnbtLJ0Y
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
